pub struct LiveSourceProvider { /* private fields */ }Expand description
Swappable TableProvider for streaming micro-batch execution.
scan() returns an internal execution plan that reads from the shared
batch slot at execute() time — enabling physical plan caching.
Implementations
Sourceimpl LiveSourceProvider
impl LiveSourceProvider
Sourcepub fn new(schema: SchemaRef) -> Self
pub fn new(schema: SchemaRef) -> Self
Creates a provider with the given schema and an empty batch slot.
Sourcepub fn handle(&self) -> LiveSourceHandle
pub fn handle(&self) -> LiveSourceHandle
Returns a handle for swapping batches into this provider.