pub struct LookupJoinNode { /* private fields */ }Expand description
Custom logical plan node for a lookup join.
Represents a join between a streaming input plan and a lookup table. The lookup table is not a DataFusion table; it is resolved at execution time via the lookup source connector.
Implementations
Sourceimpl LookupJoinNode
impl LookupJoinNode
Sourcepub fn new(
input: LogicalPlan,
lookup_table: String,
lookup_schema: DFSchemaRef,
join_keys: Vec<JoinKeyPair>,
join_type: LookupJoinType,
pushdown_predicates: Vec<Expr>,
required_lookup_columns: HashSet<String>,
output_schema: DFSchemaRef,
metadata: LookupTableMetadata,
) -> Self
pub fn new( input: LogicalPlan, lookup_table: String, lookup_schema: DFSchemaRef, join_keys: Vec<JoinKeyPair>, join_type: LookupJoinType, pushdown_predicates: Vec<Expr>, required_lookup_columns: HashSet<String>, output_schema: DFSchemaRef, metadata: LookupTableMetadata, ) -> Self
Creates a new lookup join node.
Sourcepub fn with_local_predicates(self, predicates: Vec<Expr>) -> Self
pub fn with_local_predicates(self, predicates: Vec<Expr>) -> Self
Sets predicates to be evaluated locally after the join.
Sourcepub fn with_aliases(
self,
lookup_alias: Option<String>,
stream_alias: Option<String>,
) -> Self
pub fn with_aliases( self, lookup_alias: Option<String>, stream_alias: Option<String>, ) -> Self
Sets table aliases for qualified column resolution.
Sourcepub fn lookup_table_name(&self) -> &str
pub fn lookup_table_name(&self) -> &str
Returns the lookup table name.
Sourcepub fn join_keys(&self) -> &[JoinKeyPair]
pub fn join_keys(&self) -> &[JoinKeyPair]
Returns the join key pairs.
Sourcepub fn join_type(&self) -> LookupJoinType
pub fn join_type(&self) -> LookupJoinType
Returns the join type.
Sourcepub fn pushdown_predicates(&self) -> &[Expr]
pub fn pushdown_predicates(&self) -> &[Expr]
Returns the pushdown predicates.
Sourcepub fn required_lookup_columns(&self) -> &HashSet<String>
pub fn required_lookup_columns(&self) -> &HashSet<String>
Returns the required lookup columns.
Sourcepub fn metadata(&self) -> &LookupTableMetadata
pub fn metadata(&self) -> &LookupTableMetadata
Returns the lookup table metadata.
Sourcepub fn lookup_schema(&self) -> &DFSchemaRef
pub fn lookup_schema(&self) -> &DFSchemaRef
Returns the lookup table schema.
Sourcepub fn local_predicates(&self) -> &[Expr]
pub fn local_predicates(&self) -> &[Expr]
Returns the local predicates (evaluated after the join).
Sourcepub fn lookup_alias(&self) -> Option<&str>
pub fn lookup_alias(&self) -> Option<&str>
Returns the lookup table alias.
Sourcepub fn stream_alias(&self) -> Option<&str>
pub fn stream_alias(&self) -> Option<&str>
Returns the stream input alias.