pub struct CumulateWindowStart { /* private fields */ }Expand description
Computes the cumulate window epoch start for a given timestamp.
cumulate(timestamp, step, size) returns floor(ts / size) * size,
which is the epoch start for the cumulating window that contains ts.
The actual multi-window assignment (one row per cumulating window) is
handled by Ring 0 operators.
Arguments
- Arg 0: Timestamp column or scalar (
TimestampMillisecondorInt64ms) - Arg 1: Step interval scalar (window growth increment)
- Arg 2: Max size interval scalar (epoch size)
Implementations