Module error

Module error 

Error translation layer for DataFusion errors.

Translates internal DataFusion/Arrow error messages into user-friendly LaminarDB errors with structured error codes (LDB-NNNN) and hints.

Error Code Ranges

RangeCategory
LDB-1001..LDB-1099SQL syntax errors
LDB-1100..LDB-1199Schema / column errors
LDB-1200..LDB-1299Type errors
LDB-2000..LDB-2099Window / watermark errors
LDB-3000..LDB-3099Join errors
LDB-9000..LDB-9099Internal errors

Modules

codes
Structured error code constants.
suggest
Edit-distance based suggestions for typo correction.

Structs

TranslatedError
A translated error with structured code, message, and optional hint.

Functions

suggest_column
Suggests a column name correction based on edit distance.
translate_datafusion_error
Translates a DataFusion error message into a user-friendly TranslatedError.
translate_datafusion_error_with_context
Like translate_datafusion_error but accepts an optional list of available column names for typo suggestions.