pub struct LateDataClause {
pub allowed_lateness: Option<Box<Expr>>,
pub side_output: Option<String>,
}Expand description
Late data handling clause.
Controls what happens to events that arrive after their window has closed.
This is the SQL AST representation of late data configuration.
See laminar_core::operator::window::LateDataConfig for the runtime representation.
Fields
allowed_lateness: Option<Box<Expr>>Allowed lateness duration (e.g., INTERVAL '1' HOUR)
side_output: Option<String>Side output name for late events (e.g., late_events)
Implementations
Sourceimpl LateDataClause
impl LateDataClause
Sourcepub fn with_allowed_lateness(lateness: Expr) -> Self
pub fn with_allowed_lateness(lateness: Expr) -> Self
Creates a clause with allowed lateness only.
Sourcepub fn with_side_output(lateness: Expr, side_output: String) -> Self
pub fn with_side_output(lateness: Expr, side_output: String) -> Self
Creates a clause with both allowed lateness and side output.
Sourcepub fn side_output_only(side_output: String) -> Self
pub fn side_output_only(side_output: String) -> Self
Creates a clause with side output only (uses default lateness).
Sourcepub fn to_allowed_lateness(&self) -> Result<Duration, ParseError>
pub fn to_allowed_lateness(&self) -> Result<Duration, ParseError>
Convert to allowed lateness Duration.
Errors
Returns ParseError::WindowError if the interval cannot be parsed.
Sourcepub fn has_side_output(&self) -> bool
pub fn has_side_output(&self) -> bool
Check if this clause has a side output configured.
Sourcepub fn get_side_output(&self) -> Option<&str>
pub fn get_side_output(&self) -> Option<&str>
Get the side output name, if configured.