pub struct TemporalProbeSchedule { /* private fields */ }Expand description
Validated target-time schedule for one temporal-join state machine.
Implementations
Sourceimpl TemporalProbeSchedule
impl TemporalProbeSchedule
Sourcepub fn list(offsets_ms: Vec<i64>) -> Result<Self, String>
pub fn list(offsets_ms: Vec<i64>) -> Result<Self, String>
Build a validated explicit schedule.
Errors
Returns an error for an empty list, duplicate offsets, or parser-limit violations.
Sourcepub fn range(start_ms: i64, end_ms: i64, step_ms: i64) -> Result<Self, String>
pub fn range(start_ms: i64, end_ms: i64, step_ms: i64) -> Result<Self, String>
Build a validated inclusive range schedule.
Errors
Returns an error for invalid bounds, a non-positive step, a range that is not exactly divisible by its step, or parser-limit violations.
Sourcepub fn offsets_ms(&self) -> &[i64]
pub fn offsets_ms(&self) -> &[i64]
Deterministic offsets in milliseconds.
Sourcepub const fn is_multi_horizon(&self) -> bool
pub const fn is_multi_horizon(&self) -> bool
Whether the syntax requested typed offset_ms and probe_time outputs.