pub fn expand_args(args: &[ColumnarValue]) -> Result<Vec<ArrayRef>>
Expand all args to arrays of the same length.
Returns a DataFusionError if a scalar value cannot be expanded to the target length.
DataFusionError