StreamBridge

Struct StreamBridge 

pub struct StreamBridge { /* private fields */ }
Push-to-pull bridge carrying RecordBatch results from the reactor into a DataFusion query execution plan.

Implementations

Source

impl StreamBridge

pub fn new(schema: SchemaRef, capacity: usize) -> Self

Creates a new bridge with the given schema and channel capacity.

pub fn with_default_capacity(schema: SchemaRef) -> Self

Creates a new bridge with default capacity.

pub fn schema(&self) -> SchemaRef

Returns the schema for this bridge.

pub fn sender(&self) -> BridgeSender

Returns a cloneable sender for pushing batches into the bridge.

Multiple senders can be created by cloning the returned sender.

pub fn into_stream(self) -> BridgeStream

Converts this bridge into a RecordBatchStream for DataFusion.

This consumes the bridge, taking ownership of the receiver. After calling this, you can still use senders obtained from sender().

Panics

Panics if called more than once (the receiver can only be taken once).

pub fn take_stream(&mut self) -> Option<BridgeStream>

Creates a stream without consuming the bridge.

This takes ownership of the receiver, so subsequent calls will return None.