pub struct StreamBridge { /* private fields */ }Expand description
Push-to-pull bridge carrying RecordBatch results from the reactor
into a DataFusion query execution plan.
Implementations
Sourceimpl StreamBridge
impl StreamBridge
Sourcepub fn new(schema: SchemaRef, capacity: usize) -> Self
pub fn new(schema: SchemaRef, capacity: usize) -> Self
Creates a new bridge with the given schema and channel capacity.
Sourcepub fn with_default_capacity(schema: SchemaRef) -> Self
pub fn with_default_capacity(schema: SchemaRef) -> Self
Creates a new bridge with default capacity.
Sourcepub fn sender(&self) -> BridgeSender
pub fn sender(&self) -> BridgeSender
Returns a cloneable sender for pushing batches into the bridge.
Multiple senders can be created by cloning the returned sender.
Sourcepub fn into_stream(self) -> BridgeStream
pub fn into_stream(self) -> BridgeStream
Converts this bridge into a RecordBatchStream for DataFusion.
This consumes the bridge, taking ownership of the receiver.
After calling this, you can still use senders obtained from sender().
Panics
Panics if called more than once (the receiver can only be taken once).
Sourcepub fn take_stream(&mut self) -> Option<BridgeStream>
pub fn take_stream(&mut self) -> Option<BridgeStream>
Creates a stream without consuming the bridge.
This takes ownership of the receiver, so subsequent calls will return None.